New param ``arrow`` for the ``ArrowStyle`` arrows
-------------------------------------------------

The new ``arrow`` substitutes the use of ``beginarrow``, ``beginarrow``
params in the creation of arrows. It receives arrows strings like '<-',
']-[' and ']->'.